Module blaxel.core.client.models.integration_endpoint_token
===========================================================

Classes
-------

`IntegrationEndpointToken(received: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, sent: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, total: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Integration endpoint token
    
    Attributes:
        received (Union[Unset, str]): Integration endpoint token received
        sent (Union[Unset, str]): Integration endpoint token sent
        total (Union[Unset, str]): Integration endpoint token total
    
    Method generated by attrs for class IntegrationEndpointToken.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `received: blaxel.core.client.types.Unset | str`
    :

    `sent: blaxel.core.client.types.Unset | str`
    :

    `total: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :